package de.fraunhofer.iem.dataprovider.gitlab

import de.fraunhofer.iem.dataprovider.logger.getLogger
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

enum class Platform {
    OPEN_CODE,
    GITHUB,
}
data class RepositoryChangedDto(val repoId: Long, val platform: Platform)
data class RepositoryChangedPathDto(val path: String, val platform: Platform)
@RestController
@RequestMapping("/gitlab")
class GitlabController(private val gitlabService: GitlabService) {

    private val logger = getLogger(javaClass)

    // TODO: if the parsing of the request body fails we send a stack
    //  trace back this should be changed to a custom error.
    @PostMapping("/repoChanged")
    suspend fun repoChanged(@RequestBody repositoryChangedDto: RepositoryChangedDto) {
        logger.info("Repo changed POST request for ID ${repositoryChangedDto.repoId} on platform ${repositoryChangedDto.platform} received.")
        when (repositoryChangedDto.platform) {
            Platform.OPEN_CODE -> gitlabService.queryOpenCodeProject(repositoryChangedDto.repoId)
            else -> {
                logger.info("Platform currently not supported.")
                // TODO: send fitting http response
            }
        }
    }

    // TODO: improve duplicate code from repoChanged
    @PostMapping("/repoChangedPath")
    suspend fun repoChangedPath(@RequestBody repositoryChangedDto: RepositoryChangedPathDto) {
        logger.info("Repo changed POST request for path ${repositoryChangedDto.path} on platform ${repositoryChangedDto.platform} received.")
        when (repositoryChangedDto.platform) {
            Platform.OPEN_CODE -> gitlabService.queryOpenCodeProject(repositoryChangedDto.path)
            else -> {
                logger.info("Platform currently not supported.")
                // TODO: send fitting http response
            }
        }
    }
}